@@ -72,7 +72,8 @@ class Entity():
             self._component_manager.create_component(value)
             
     def __delitem__(self, key):
-        self._components.pop(key)
+        component = self._components.pop(key)
+        component.destroy()
 
     def __getattr__(self, key):
         if key in super().__getattribute__('__slots__'):
@@ -94,7 +95,8 @@ class Entity():
                 self._component_manager.create_component(value)
                 
     def __delattr__(self, key):
-        self._components.pop(key)
+        component = self._components.pop(key)
+        component.destroy()
 
 
     def create(self, entity_manager, component_manager):
